import click
from rich.console import Console
import os
import sys
sys.path.insert(0, os.path.abspath(".")) # guarentees that the path of this is added. Please work.

from cli.utils.handlers import UserAgentHandler

from cli.commands.alerts import alerts
from cli.commands.intro import intro
from cli.commands.useragent import user_agent_group

# This is the common entry point, and is called when you type richwx into the console.
@click.group()
@click.pass_context
def cli(ctx):
    """A fun little CLI tool that utilizes the National Weather Service API to display
    weather data in the terminal."""
        
    ctx.obj = {'console' : Console(),
                'user_agent' : UserAgentHandler(),
              }

# Add the commands here.
cli.add_command(intro)
cli.add_command(alerts)
cli.add_command(user_agent_group)

if __name__ == '__main__':
    cli()


from setuptools import setup, find_packages
from pathlib import Path

# The directory containing this file
HERE = Path(__file__).parent
README = (HERE / "README.md").read_text()

version = '0.0.3'

setup(
        name = 'richwx',
        version = version,
        packages = find_packages(),
        license='apache-2.0',
        entry_points = {
                'console_scripts': [
                'richwx = cli.cli:cli', # cli_folder.cli_file:cli_function
                ],
        },
        install_requires = [
                'Click',
                'rich',
                'nwsapy'
        ],
        url = 'https://github.com/WxBDM/richwx', 
        download_url = f'https://github.com/WxBDM/richwx/archive/refs/tags/v{version}.tar.gz', 
        python_requires = '>=3.8',
        classifiers=[
                'Development Status :: 3 - Alpha',
                'Intended Audience :: Developers',   
                'Topic :: Software Development :: Build Tools',
                'License :: OSI Approved :: Apache Software License',
                'Programming Language :: Python :: 3.8',
                'Programming Language :: Python :: 3.9',
                'Programming Language :: Python :: 3.10'
                ],
        author = 'Brandon Molyneaux', 
        email = 'bran.moly@gmail.com',  
        long_description=README,
        long_description_content_type="text/markdown",
     )